---
name: 🐛 Bug report
about: Create a report to help us repair something that is currently broken
labels: bug
---

<!-- Thank you for contributing. These HTML comments will not render in the issue, but you can delete them once you've read them if you prefer! -->

<!-- Before creating a new issue, please search for relevant issues.
-->

## Description

<!--Describe the bug clearly and concisely. Include screenshots if possible-->

## Reproduce

<!--Describe step-by-step instructions to reproduce the behavior-->

1. Go to '...'
1. Click on '...'
1. Scroll down to '...'
1. See error '...'

<!--Describe how you diagnosed the issue-->

## Expected behavior

<!--Describe what you expected to happen-->

## Context

<!--Complete the following for context, and add any other relevant context-->

- Operating System and version:
- Browser and version(if necessary):
- Which version are you using:

<details><summary>Error message</summary>
<pre>
Paste complete error message, logs, or stack traces here.
</pre>
</details>

<details><summary>Configuration</summary>
<pre>
Paste the contents of your configuration file here.
</pre>
</details>

<details><summary>Additional context</summary>
<pre>
Add any other context about the problem here.
</pre>
</details>
